#!/bin/gnuplot

set datafile separator ","
set output 'plot.pdf' 

set yrange [0:*]

set xdata time
set timefmt "%Y-%m-%d %H:%M"
set format x "%Y-%m-%d"
set xrange ["2019-07-01":"2022-07-01"]
set grid 
set xtics rotate by 45
set key top left


set terminal pdf  color enhanced size 7,5 dashed
if (!exists("MP_LEFT"))   MP_LEFT = .1
if (!exists("MP_RIGHT"))  MP_RIGHT = .95
if (!exists("MP_BOTTOM")) MP_BOTTOM = .14
if (!exists("MP_TOP"))    MP_TOP = .95
if (!exists("MP_xGAP"))   MP_xGAP = 0.1
if (!exists("MP_yGAP"))   MP_yGAP = 0.02

set multiplot layout 2,2 columnsfirst margins screen MP_LEFT, MP_RIGHT, MP_BOTTOM, MP_TOP spacing screen MP_xGAP, MP_yGAP

set linetype 2 dashtype 2

set key bottom left
set xtics textcolor rgbcolor "white"
set ylabel "{/Arial:Bold B2a}: AAI-connected centres \n with users in AAI"
set yrange [0:20]
plot '../stats/aai/aai_centers.csv' u 1:($2>0?$2:1/0)   w lp pt 7 ps 0.5 lc black notitle ,\
     ''                             u 1:($2<=11?$2:1/0) w lp pt 6 ps 0.5 lc black lt 2 notitle
set yrange [0:*]

set timefmt "%d.%m.%Y"
set xtics textcolor rgbcolor "black" offset -4,-3
set ylabel '{/Arial:Bold B2c}: Registered end users'
plot '../stats/aai/aai_users.csv' u 1:2 w lp pt 7 ps 0.5 lc black notitle

set timefmt "%d.%m.%y"
set xtics textcolor rgbcolor "white"
set ylabel "{/Arial:Bold B2b}: AAI-connected services \n (incl. \"associated services\")"
plot '../stats/aai/aai_services.csv' u 1:2 w lp pt 7 ps 0.5 lc black notitle

set key top left
set timefmt "%d.%m.%Y"
set xtics textcolor rgbcolor "black" offset -4,-3
set ylabel '{/Arial:Bold B2d}: Registered VOs (root)'
plot '../stats/aai/aai_vo.csv' u 1:2 w lp pt 6 ps 0.5 lt 2 lc black title 'VO - total' ,\
     ''                        u 1:3 w lp pt 7 ps 0.5 lt 1 lc black title 'VO - HIFIS' 
set timefmt "%Y-%m-%d %H:%M"
              
              
unset multiplot



set key bottom left
set ylabel '{/Arial:Bold B2a}: AAI-connected centres'
set xtics textcolor rgbcolor "black" offset -4,0
set yrange [0:20]
plot '../stats/aai/aai_centers.csv' u 1:2 w lp pt 7 ps 0.5 lc black title 'IdPs with users in AAI' ,\
     '../stats/aai/aai_idp_attribute_query.csv' u 1:2 w lp pt 6 ps 0.5 lc black title 'IdPs supporting attribute query'



set logscale y
set yrange [10:4000]
set timefmt "%d.%m.%Y"
set ylabel '{/Arial:Bold B2c}: Registered end users'
plot '../stats/aai/aai_users.csv' u 1:2 w lp pt 7 ps 0.5 lc black notitle
unset logscale y

set yrange [0:*]
set timefmt "%Y-%m-%d %H:%M"
set ylabel 'B1: Centres connected to Backbone'
plot '../stats/vpn/data.csv' u 1:2 w lp pt 7 ps 0.5 lc black notitle
